@@ -15,6 +15,7 @@ use strict;
 
 package Data::FormValidator::Results;
 
+use Carp;
 use Symbol;
 use Data::FormValidator::Filters qw/:filters/;
 use Data::FormValidator::Constraints (qw/:validators :matchers/);
@@ -22,7 +23,7 @@ use vars qw/$AUTOLOAD $VERSION/;
 use overload
   'bool' => \&_bool_overload_based_on_success;
 
-$VERSION = 4.01;
+$VERSION = 4.02;
 
 =pod
 
@@ -97,6 +98,7 @@ sub _process {
     # import valid_* subs from requested packages
 	foreach my $package (_arrayify($profile->{validator_packages})) {
 		if ( !exists $imported_validators{$package} ) {
+			local $SIG{__DIE__}  = \&confess;
 			eval "require $package";
 			if ($@) {
 				die "Couldn't load validator package '$package': $@";
@@ -715,12 +717,14 @@ sub prefix_hash {
 sub _create_sub_from_RE {
 	my $re = shift || return undef;
 	my $untaint_this = shift;
+    my $force_method_p = shift;
 
 	my $sub;
 	# If it's "qr" style
 	if (substr($re,0,1) eq '(') {
 		$sub = sub { 
-            my $val = shift;
+            # With methods, the value is the second argument
+            my $val = $force_method_p ? $_[1] : $_[0];
 			my ($match) = ($val =~ $re); 
 			if ($untaint_this && defined $match) {
                 # pass the value through a RE that matches anything to untaint it.
@@ -734,8 +738,15 @@ sub _create_sub_from_RE {
 
 	}
 	else {
+        local $SIG{__DIE__}  = \&confess;
         my $return_code = ($untaint_this) ? '; return ($& =~ m/(.*)/s)[0] if defined($`);' : '';
-		$sub = eval 'sub { $_[0] =~ '.$re.$return_code. '}';
+        # With methods, the value is the second argument
+        if ($force_method_p) {
+            $sub = eval 'sub { $_[1] =~ '.$re.$return_code. '}';
+        }
+        else {
+            $sub = eval 'sub { $_[0] =~ '.$re.$return_code. '}';
+        }
 	    die "Error compiling regular expression $re: $@" if $@;
 	}
 	return $sub;
@@ -790,8 +801,9 @@ sub _filter_apply {
 # $constraint_href = $self->_constraint_hash_build($spec,$untaint_p)
 #
 # Input:
-#   - $spec     # Any constraint valid in the profile
-#   - $untaint  # bool for whether we could try to untaint the field. 
+#   - $spec           # Any constraint valid in the profile
+#   - $untaint        # bool for whether we could try to untaint the field. 
+#   - $force_method_p # bool for if it's  a method ?
 #
 # Output:
 #  - $constraint_hashref
@@ -802,8 +814,8 @@ sub _filter_apply {
 # 		is_method  - bool for whether this was a 'constraint' or 'constraint_method'
 
 sub _constraint_hash_build {
-	my ($self,$constraint_spec,$untaint_this) = @_;
-	die "_constraint_hash_build received wrong number of arguments" unless (scalar @_ == 3);
+	my ($self,$constraint_spec,$untaint_this,$force_method_p) = @_;
+	die "_constraint_hash_build received wrong number of arguments" unless (scalar @_ == 4);
 
 	my	$c = {
 			name 		=> $constraint_spec,
@@ -821,7 +833,7 @@ sub _constraint_hash_build {
 	# Check for regexp constraint
 	if ((ref $c->{constraint} eq 'Regexp')
 			or ( $c->{constraint} =~ m@^\s*(/.+/|m(.).+\2)[cgimosx]*\s*$@ )) {
-		$c->{constraint} = _create_sub_from_RE($c->{constraint},$untaint_this);
+		$c->{constraint} = _create_sub_from_RE($c->{constraint},$untaint_this,$force_method_p);
 	}
 	# check for code ref
 	elsif (ref $c->{constraint} eq 'CODE') {
@@ -840,6 +852,7 @@ sub _constraint_hash_build {
 			}
 			# If the constraint name starts with RE_, try looking for it in the Regexp::Common package
 			elsif ($c->{constraint} =~ m/^RE_/) {
+				local $SIG{__DIE__}  = \&confess;
 				$c->{is_method} = 1;
 				$c->{constraint} = eval 'sub { &_create_regexp_common_constraint(@_)}' 
 					|| die "could not create Regexp::Common constraint: $@";
@@ -851,6 +864,7 @@ sub _constraint_hash_build {
 			# try to use match_* first
 			my $routine = 'match_'.$c->{constraint};			
 			if (defined *{qualify_to_ref($routine)}{CODE}) {
+				local $SIG{__DIE__}  = \&confess;
 				$c->{constraint} = eval 'sub { no strict qw/refs/; return defined &{"match_'.$c->{constraint}.'"}(@_)}';
 			}
 			# match_* doesn't exist; if it is supposed to be from the
@@ -860,6 +874,7 @@ sub _constraint_hash_build {
 			}
 			# Load it from Regexp::Common 
 			elsif ($c->{constraint} =~ m/^RE_/) {
+				local $SIG{__DIE__}  = \&confess;
 				$c->{is_method} = 1;
 				$c->{constraint} = eval 'sub { return defined &_create_regexp_common_constraint(@_)}' ||
 					die "could not create Regexp::Common constraint: $@";
@@ -1033,7 +1048,7 @@ sub _add_constraints_from_map {
 					else {
 						$result{$key} = $new;
 					}
-					warn "constraint_regexp_map: $key matches\n" if $profile->{debug};
+					warn "$map_name: $key matches\n" if $profile->{debug};
 				}
 			}
 	}
@@ -1086,7 +1101,7 @@ sub _check_constraints {
 			# from being accidently shared
 			$self->{__CURRENT_CONSTRAINT_NAME} = undef;
 
-			my $c = $self->_constraint_hash_build($constraint_spec,$untaint_this);
+			my $c = $self->_constraint_hash_build($constraint_spec,$untaint_this, $force_method_p);
 			$c->{is_method} = 1 if $force_method_p;
 
 			my $is_value_list = 1 if (ref $valid->{$field} eq 'ARRAY');
